==> mapnik_2.0.0+ds1.orig.tar.gz: mapnik-2.0.0/include/mapnik/svg/svg_path_parser.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2010 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef SVG_PATH_PARSER_HPP
#define SVG_PATH_PARSER_HPP

#include <string>

namespace mapnik { namespace svg {

template <typename PathType>
bool parse_path(const char * wkt, PathType & p);

template <typename PathType>
bool parse_points(const char * wkt, PathType & p);

template <typename TransformType>
bool parse_transform(const char * wkt, TransformType & tr);

template <typename TransformType>
bool parse_transform(std::string const&  wkt, TransformType & tr);

}}


#endif // SVG_PATH_PARSER_HPP

==> mapnik_2.2.0+ds1.orig.tar.gz: mapnik-2.2.0/include/mapnik/svg/svg_path_parser.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2011 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef MAPNIK_SVG_PATH_PARSER_HPP
#define MAPNIK_SVG_PATH_PARSER_HPP

#include <mapnik/config.hpp>
#include <string>

namespace mapnik { namespace svg {

    template <typename PathType>
    bool parse_path(const char * wkt, PathType & p);

    template <typename PathType>
    bool parse_points(const char * wkt, PathType & p);

    template <typename TransformType>
    bool MAPNIK_DECL parse_transform(const char * wkt, TransformType & tr);

//template <typename TransformType>
//bool MAPNIK_DECL parse_transform(std::string const&  wkt, TransformType & tr);

    }}

#endif // MAPNIK_SVG_PATH_PARSER_HPP
